@@ -100,7 +100,7 @@ class ContractProposal:
     # Start price is not an actual contract parameter, but one of start price, leverage,
     # or separated side inputs are needed in order for the contract to be fully specified.
     start_price_oracleUnits_per_bch: ScriptPriceInOracleUnitsPerBch
-    low_liquidation_price_oracleUnits_per_bch: ScriptPriceInOracleUnitsPerBch
+    long_liquidation_price_oracleUnits_per_bch: ScriptPriceInOracleUnitsPerBch
     oracle_public_key: PublicKey
 
     # Relationship between Roles and Sides
@@ -115,7 +115,7 @@ class ContractProposal:
     ###############
     @property
     def total_input_sats(self) -> UtxoSats:
-        return UtxoSats(ceil(self.nominal_oracleUnits_x_satsPerBch / self.low_liquidation_price_oracleUnits_per_bch))
+        return UtxoSats(ceil(self.nominal_oracleUnits_x_satsPerBch / self.long_liquidation_price_oracleUnits_per_bch))
 
     @property
     def hedge_input_sats(self) -> UtxoSats:
@@ -131,6 +131,11 @@ class ContractProposal:
     def oracle_unit_cls(self) -> Type[OracleUnit]:
         return oracle_pubkey_to_unit_class[self.oracle_public_key]
 
+    @property
+    def short_liquidation_price_oracleUnits_per_bch(self) -> ScriptPriceInOracleUnitsPerBch | None:
+        # Until two-sided leverage is enabled in AnyHedge, this is always None
+        return None
+
     ###############
     # Approximate unit versions of the inputs
     ###############
@@ -159,7 +164,7 @@ class ContractProposal:
 
     @property
     def effective_long_leverage(self) -> LongLeverage:
-        return LongLeverage(1 / (1 - self.low_liquidation_price_oracleUnits_per_bch / self.start_price_oracleUnits_per_bch))
+        return LongLeverage(1 / (1 - self.long_liquidation_price_oracleUnits_per_bch / self.start_price_oracleUnits_per_bch))
 
     ###############
     # Sided views
@@ -210,7 +215,7 @@ class ContractProposal:
             maturity_timestamp=maturity_timestamp,
             nominal_oracleUnits_x_satsPerBch=nominal_oracleUnits_x_satsPerBch,
             start_price_oracleUnits_per_bch=start_price_oracleUnits_per_bch,
-            low_liquidation_price_oracleUnits_per_bch=low_liquidation_price_oracleUnits_per_bch,
+            long_liquidation_price_oracleUnits_per_bch=low_liquidation_price_oracleUnits_per_bch,
             oracle_public_key=nominal_oracleUnits.public_key,
             maker_side=maker_side,
         )
@@ -328,7 +333,7 @@ class ContractFunding:
                ) -> ContractRedemption:
         """Redeem the contract according to market conditions or raise an unredeemable error for invalid conditions."""
         reached_maturity_time = price_timestamp >= self.base_proposal.maturity_timestamp
-        reached_liquidation_price = price_oracleUnits_per_bch <= self.base_proposal.low_liquidation_price_oracleUnits_per_bch
+        reached_liquidation_price = price_oracleUnits_per_bch <= self.base_proposal.long_liquidation_price_oracleUnits_per_bch
         if reached_maturity_time or force_maturity:
             # Maturation, even in the case of a liquidation price
             return ContractRedemption(
@@ -360,7 +365,7 @@ class ContractRedemption:
 
     @property
     def clamped_end_price_oracleUnits_per_bch(self) -> ScriptPriceInOracleUnitsPerBch:
-        return max(self.naive_end_price_oracleUnits_per_bch, self.base_funding.base_proposal.low_liquidation_price_oracleUnits_per_bch)
+        return max(self.naive_end_price_oracleUnits_per_bch, self.base_funding.base_proposal.long_liquidation_price_oracleUnits_per_bch)
 
     @property
     def total_payout_sats(self) -> UtxoSats:
