@@ -47,10 +47,19 @@ START_PRICE_USDEM2_PER_BCH = ScriptPriceInOracleUnitsPerBch(200_00)  # $200.00 /
 # = NominalOracleUnitsXSatsPerBch(round(NOMINAL_USDEM2 * SATS_PER_BCH))
 DERIVED_NOMINAL_UNITS_X_SATS_PER_BCH = NominalOracleUnitsXSatsPerBch(1_000_000_000_000)
 
-# Liquidation Price is the price where total bch covers exactly nominal units
+# Long liquidation Price is the price where total bch covers exactly nominal units
+# At this price, the long party is liquidated (has no funds remaining in the contract)
 # Calculate as round(START_PRICE_USDEM2_PER_BCH * (1 - 1 / LONG_LEVERAGE))
 # $155.56 / BCH
-DERIVED_LOW_LIQUIDATION_PRICE = ScriptPriceInOracleUnitsPerBch(155_56)
+DERIVED_LONG_LIQUIDATION_PRICE = ScriptPriceInOracleUnitsPerBch(155_56)
+
+# Short liquidation Price is the price where the short party is
+# liquidated (has no funds remaining in the contract). In the current design of
+# AnyHedge where hedge is always a 1x short, there is no meaningful short
+# liquidation price. In the real contract, there is a "high" settlement price
+# that can trigger early settlement, but it is an unused contract feature
+# rather than a liquidation price.
+NO_SHORT_LIQUIDATION_PRICE = None
 
 # The bch amount to cover the initial nominal units at the start price
 # = round(NOMINAL_USDEM2 * SATS_PER_BCH / START_PRICE_USDEM2_PER_BCH)
@@ -99,8 +108,12 @@ class TestContractProposalDerivedValues(unittest.TestCase):
     def test_nominal_oracleUnits_x_satsPerBch(self):
         self.assertEqual(standard_contract_proposal().nominal_oracleUnits_x_satsPerBch, DERIVED_NOMINAL_UNITS_X_SATS_PER_BCH)
 
-    def test_low_liquidation_price_oracleUnits_per_bch(self):
-        self.assertEqual(standard_contract_proposal().low_liquidation_price_oracleUnits_per_bch, DERIVED_LOW_LIQUIDATION_PRICE)
+    def test_long_liquidation_price_oracleUnits_per_bch(self):
+        self.assertEqual(standard_contract_proposal().long_liquidation_price_oracleUnits_per_bch, DERIVED_LONG_LIQUIDATION_PRICE)
+
+    def test_short_liquidation_price_oracleUnits_per_bch(self):
+        # Until two-sided leverage is enabled in AnyHedge, this is always None
+        self.assertEqual(standard_contract_proposal().short_liquidation_price_oracleUnits_per_bch, NO_SHORT_LIQUIDATION_PRICE)
 
     def test_maker_side(self):
         self.assertEqual(standard_contract_proposal().maker_side, Side.HEDGE)
@@ -293,7 +306,7 @@ BEFORE_MATURITY_TIMESTAMP = ScriptTimestamp(MATURITY_TIMESTAMP - 1)
 
 # A valid maturity price, just somewhat over the start price so no chance of low liquidation
 NAIVE_MATURITY_PRICE_USDEM2_PER_BCH = ScriptPriceInOracleUnitsPerBch(220_00)  # $220.00
-BELOW_LIQUIDATING_PRICE_USDEM2_PER_BCH = ScriptPriceInOracleUnitsPerBch(DERIVED_LOW_LIQUIDATION_PRICE - 10)
+BELOW_LIQUIDATING_PRICE_USDEM2_PER_BCH = ScriptPriceInOracleUnitsPerBch(DERIVED_LONG_LIQUIDATION_PRICE - 10)
 
 
 class TestMaturityRedemption(unittest.TestCase):
@@ -308,7 +321,7 @@ class TestMaturityRedemption(unittest.TestCase):
     def test_matures_at_maturity_time_even_if_liquidating_price(self):
         redemption = standard_contract_funding().redeem(
             price_timestamp=MATURITY_TIMESTAMP,
-            price_oracleUnits_per_bch=DERIVED_LOW_LIQUIDATION_PRICE,
+            price_oracleUnits_per_bch=DERIVED_LONG_LIQUIDATION_PRICE,
             force_maturity=False,
         )
         self.assertEqual(redemption.redemption_type, RedemptionType.MATURATION)
@@ -324,14 +337,14 @@ class TestMaturityRedemption(unittest.TestCase):
     def test_liquidates_before_maturity_time_at_low_liquidation_price(self):
         redemption = standard_contract_funding().redeem(
             price_timestamp=BEFORE_MATURITY_TIMESTAMP,
-            price_oracleUnits_per_bch=DERIVED_LOW_LIQUIDATION_PRICE,
+            price_oracleUnits_per_bch=DERIVED_LONG_LIQUIDATION_PRICE,
             force_maturity=False,
         )
         self.assertEqual(redemption.redemption_type, RedemptionType.LIQUIDATION)
 
     def test_fails_to_liquidate_before_maturity_time_at_one_over_low_liquidation_price(self):
         valid_liquidation_timestamp = ScriptTimestamp(MATURITY_TIMESTAMP - 1)
-        one_over_liquidation_price = ScriptPriceInOracleUnitsPerBch(DERIVED_LOW_LIQUIDATION_PRICE + 1)
+        one_over_liquidation_price = ScriptPriceInOracleUnitsPerBch(DERIVED_LONG_LIQUIDATION_PRICE + 1)
         with self.assertRaises(UnredeemableError):
             standard_contract_funding().redeem(
                 price_timestamp=valid_liquidation_timestamp,
@@ -380,7 +393,7 @@ def standard_maturation(
 
 def standard_liquidation(
     price_timestamp: ScriptTimestamp = MATURITY_TIMESTAMP,
-    price_oracleUnits_per_bch: ScriptPriceInOracleUnitsPerBch = DERIVED_LOW_LIQUIDATION_PRICE,
+    price_oracleUnits_per_bch: ScriptPriceInOracleUnitsPerBch = DERIVED_LONG_LIQUIDATION_PRICE,
     force_maturity: bool = False,
 ):
     return standard_contract_funding().redeem(
